==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/CUSTOMFIELDSEARCHCRITERIA.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROPERTYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MINVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAXVALUE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "propertycode",
    "minvalue",
    "maxvalue"
})
@XmlRootElement(name = "CUSTOMFIELDSEARCHCRITERIA")
public class CUSTOMFIELDSEARCHCRITERIA {

    @XmlElement(name = "PROPERTYCODE", required = true)
    protected String propertycode;
    @XmlElement(name = "MINVALUE")
    protected String minvalue;
    @XmlElement(name = "MAXVALUE")
    protected String maxvalue;

    /**
     * Obtient la valeur de la propriété propertycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROPERTYCODE() {
        return propertycode;
    }

    /**
     * Définit la valeur de la propriété propertycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROPERTYCODE(String value) {
        this.propertycode = value;
    }

    /**
     * Obtient la valeur de la propriété minvalue.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMINVALUE() {
        return minvalue;
    }

    /**
     * Définit la valeur de la propriété minvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMINVALUE(String value) {
        this.minvalue = value;
    }

    /**
     * Obtient la valeur de la propriété maxvalue.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMAXVALUE() {
        return maxvalue;
    }

    /**
     * Définit la valeur de la propriété maxvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMAXVALUE(String value) {
        this.maxvalue = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/CUSTOMFIELDSEARCHCRITERIA.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROPERTYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MINVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAXVALUE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "propertycode",
    "minvalue",
    "maxvalue"
})
@XmlRootElement(name = "CUSTOMFIELDSEARCHCRITERIA")
public class CUSTOMFIELDSEARCHCRITERIA {

    @XmlElement(name = "PROPERTYCODE", required = true)
    protected String propertycode;
    @XmlElement(name = "MINVALUE")
    protected String minvalue;
    @XmlElement(name = "MAXVALUE")
    protected String maxvalue;

    /**
     * Gets the value of the propertycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROPERTYCODE() {
        return propertycode;
    }

    /**
     * Sets the value of the propertycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROPERTYCODE(String value) {
        this.propertycode = value;
    }

    /**
     * Gets the value of the minvalue property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMINVALUE() {
        return minvalue;
    }

    /**
     * Sets the value of the minvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMINVALUE(String value) {
        this.minvalue = value;
    }

    /**
     * Gets the value of the maxvalue property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMAXVALUE() {
        return maxvalue;
    }

    /**
     * Sets the value of the maxvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMAXVALUE(String value) {
        this.maxvalue = value;
    }

}
